﻿using Syncfusion.UI.Xaml.Grid;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Syncfusion.Data;
using Syncfusion.UI.Xaml.Grid.Helpers;
using System.Reflection;
using Syncfusion.UI.Xaml.Grid.Cells;
using Syncfusion.UI.Xaml.Grid.Converter;
using Microsoft.Win32;
using System.IO;
using Syncfusion.XlsIO;

namespace SfDataGrid_Sample
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            var provider = this.grid.View.GetPropertyAccessProvider();

            var record = this.grid.SelectedItem;           
            var options = new ExcelExportingOptions();            

            options.CellsExportingEventHandler = cellsExportingHandler;
           
            ExcelEngine excelEngine = new ExcelEngine();
            IWorkbook workBook = excelEngine.Excel.Workbooks.Create();
            workBook.Worksheets.Create();
            this.grid.ExportToExcel(grid.View, options, workBook.Worksheets[0]);
            SaveFileDialog sfd = new SaveFileDialog
            {
                FilterIndex = 2,
                Filter = "Excel 97 to 2003 Files(*.xls)|*.xls|Excel 2007 to 2010 Files(*.xlsx)|*.xlsx"
            };

            if (sfd.ShowDialog() == true)
            {
                using (Stream stream = sfd.OpenFile())
                {
                    if (sfd.FilterIndex == 1)
                        workBook.Version = ExcelVersion.Excel97to2003;
                    else
                        workBook.Version = ExcelVersion.Excel2010;
                    workBook.SaveAs(stream);
                }

                //Message box confirmation to view the created spreadsheet.
                if (MessageBox.Show("Do you want to view the workbook?", "Workbook has been created",
                                    MessageBoxButton.YesNo, MessageBoxImage.Information) == MessageBoxResult.Yes)
                {
                    //Launching the Excel file using the default Application.[MS Excel Or Free ExcelViewer]
                    System.Diagnostics.Process.Start(sfd.FileName);
                }
            }
        }

        private void cellsExportingHandler(object sender, GridCellExcelExportingEventArgs e)
        {
            // Based on the column mapping name and the cell type, we can change the cell values when export to excel.
            if(e.CellType == ExportCellType.RecordCell && e.ColumnName == "IsClosed")
            {               
                //if the cellvalue is true, "Y" will be displayed and if the value is false, "N" will be displayed when the grid is exported into excel.
                if (e.CellValue.Equals(true))
                    e.Range.Cells[0].Value = "Y";
                else
                    e.Range.Cells[0].Value = "N";
                e.Handled = true;
            }
        }
    }
}
